# 2021-04-18 Weighted Pool

Deployment of the `WeightedPoolFactory`, for Weighted Pools of up to 8 tokens, and `WeightedPool2TokensFactory`, for Weighted Pools restricted to 2 tokens, but with an optional price oracle.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`WeightedPool` ABI](./abi/WeightedPool.json)
- [`WeightedPool2Tokens` ABI](./abi/WeightedPool2Tokens.json)
